==> zh-tpl-1.2.0.tgz: package/lib/template/umiTpl.js <==
"use strict";

/*
 * Author: lin.zehong 
 * Date: 2020-02-22 12:29:16 
 * Desc: 各种文件模板 
 */
var _require = require('../utils'),
    getNowFormatDate = _require.getNowFormatDate; // index 内容


function indexContent(pageName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, "\n* Date: ").concat(getNowFormatDate(), " \n* Desc: ").concat(pageName, " \u5165\u53E3 \n*/\nimport dynamic from 'umi/dynamic';\n\nexport default dynamic({\n  loader: () => import('./").concat(pageName, "'),\n});\n");
  return content;
} // MapProps 内容


function mapPropsContent(desc, modelName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), "\n* Desc: ").concat(desc, " MapProps \n*/\nexport const mapStateToProps = ({ ").concat(modelName, ", loading }) => ({\n  loading: loading.models.").concat(modelName, ",\n  myData: ").concat(modelName, ".myData,\n});\n\nexport const mapDispatchToProps = dispatch => ({\n  onUpdate(payload) {\n    dispatch({\n      type: '").concat(modelName, "/update',\n      payload,\n    });\n  },\n  clearData(payload) {\n    dispatch({\n      type: '").concat(modelName, "/clearData',\n      payload,\n    });\n  },\n});\n");
  return content;
} // 入口组件内容


function pContent(pageName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), " \n* Desc: \u63CF\u8FF0\n*/\nimport React from 'react';\nimport { connect } from \"dva\";\nimport { mapStateToProps, mapDispatchToProps } from \"./MapProps\";\nimport styles from './").concat(pageName, ".less';\n\nconst ").concat(pageName, " = () => {\n  return (\n    <div className={styles.root}>\n      \u5185\u5BB9\n    </div>\n  )\n}\n\nexport default connect(mapStateToProps, mapDispatchToProps)(").concat(pageName, ");\n");
  return content;
} // less 内容


function lessContent() {
  var content = ".root{\n  :global{\n\n  }\n}\n";
  return content;
} // services 内容


function servicesContent(string, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), " \n* Desc: ").concat(string, " services \n*/\nimport { get } from 'utils/request';\n\n/** \u63A5\u53E3\u540D\u79F0\n* @param {string} id -\u6240\u5C5E\u4FE1\u606F\u7684id\n*/\nexport const cityDataShow = param => get('/epidemic/cityDataShow', param);\n");
  return content;
} // models 内容


function modelsContent(fileName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), " \n* Desc: ").concat(fileName, " models \n*/\nimport * as ").concat(fileName, "Api from '../services/").concat(fileName, ".js';\n\nconst initData = {\n  myData: [], // \u6570\u636E\n};\n\nexport default {\n  namespace: '").concat(fileName, "',\n  state: {\n    ...initData,\n  },\n\n  effects: {\n    *cityDataShow({ payload }, { call, put }) {\n      const result = yield call(").concat(fileName, "Api.cityDataShow, payload);\n      const { errCode, data } = result;\n      if (errCode === 0) {\n        yield put({\n          type: 'update',\n          payload: {\n            myData: data || [],\n          },\n        });\n      }\n      return result;\n    },\n  },\n  reducers: {\n    update: (state, { payload }) => ({\n      ...state,\n      ...payload,\n    }),\n    clearData: () => ({ ...initData }),\n  },\n};\n\n");
  return content;
}

module.exports = {
  indexContent: indexContent,
  mapPropsContent: mapPropsContent,
  pContent: pContent,
  lessContent: lessContent,
  servicesContent: servicesContent,
  modelsContent: modelsContent
};

==> zh-tpl-2.0.0.tgz: package/lib/template/umiTpl.js <==
"use strict";

/*
 * Author: lin.zehong 
 * Date: 2020-02-22 12:29:16 
 * Desc: 各种文件模板 
 */
var _require = require('../utils'),
    getNowFormatDate = _require.getNowFormatDate; // index 内容


function indexContent(pageName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, "\n* Date: ").concat(getNowFormatDate(), " \n* Desc: ").concat(pageName, " \u5165\u53E3 \n*/\nimport dynamic from 'umi/dynamic';\n\nexport default dynamic({\n  loader: () => import('./").concat(pageName, "'),\n});\n");
  return content;
} // MapProps 内容


function mapPropsContent(desc, modelName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), "\n* Desc: ").concat(desc, " MapProps \n*/\nexport const mapStateToProps = ({ ").concat(modelName, ", loading }) => ({\n  loading: loading.models.").concat(modelName, ",\n  myData: ").concat(modelName, ".myData,\n});\n\nexport const mapDispatchToProps = dispatch => ({\n  onUpdate(payload) {\n    dispatch({\n      type: '").concat(modelName, "/update',\n      payload,\n    });\n  },\n  clearData(payload) {\n    dispatch({\n      type: '").concat(modelName, "/clearData',\n      payload,\n    });\n  },\n});\n");
  return content;
} // 入口组件内容


function pContent(pageName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), " \n* Desc: \u63CF\u8FF0\n*/\nimport React from 'react';\nimport { connect } from 'dva';\nimport { mapStateToProps, mapDispatchToProps } from './MapProps';\nimport styles from './").concat(pageName, ".less';\n\nconst ").concat(pageName, " = () => {\n  return (\n    <div className={styles.root}>\n      \u5185\u5BB9\n    </div>\n  )\n}\n\nexport default connect(mapStateToProps, mapDispatchToProps)(").concat(pageName, ");\n");
  return content;
} // less 内容


function lessContent() {
  var content = ".root{\n  :global{\n\n  }\n}\n";
  return content;
} // services 内容


function servicesContent(string, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), " \n* Desc: ").concat(string, " services \n*/\nimport { get } from 'utils/fetch';\n\n/** \u63A5\u53E3\u540D\u79F0\n* @param {string} id -\u6240\u5C5E\u4FE1\u606F\u7684id\n*/\nexport const cityDataShow = param => get('/epidemic/cityDataShow', param);\n");
  return content;
} // models 内容


function modelsContent(fileName, options) {
  var author = options.author;
  var content = "/*\n* Author: ".concat(author, " \n* Date: ").concat(getNowFormatDate(), " \n* Desc: ").concat(fileName, " models \n*/\nimport * as ").concat(fileName, "Api from '../services/").concat(fileName, ".js';\n\nconst initData = {\n  myData: [], // \u6570\u636E\n};\n\nexport default {\n  namespace: '").concat(fileName, "',\n  state: {\n    ...initData,\n  },\n\n  effects: {\n    *cityDataShow({ payload }, { call, put }) {\n      const result = yield call(").concat(fileName, "Api.cityDataShow, payload);\n      const { errCode, data } = result;\n      if (errCode === 0) {\n        yield put({\n          type: 'update',\n          payload: {\n            myData: data || [],\n          },\n        });\n      }\n      return result;\n    },\n  },\n  reducers: {\n    update: (state, { payload }) => ({\n      ...state,\n      ...payload,\n    }),\n    clearData: () => ({ ...initData }),\n  },\n};\n\n");
  return content;
}

module.exports = {
  indexContent: indexContent,
  mapPropsContent: mapPropsContent,
  pContent: pContent,
  lessContent: lessContent,
  servicesContent: servicesContent,
  modelsContent: modelsContent
};
